/*
 * IRC - Internet Relay Chat, ircd/p_check.c
 * Copyright (C) 1990 Jarkko Oikarinen and
 * University of Oulu, Computing Center
 *
 * See file AUTHORS in IRC package for additional names of
 * the programmers.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 1, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "channel.h"
#include "client.h"
#include "hash.h"
#include "ircd.h"
#include "ircd_string.h"
#include "numeric.h"
#include "send.h"
#include "p_checkfunc.h"
#include "patch.h"


/* --------------------------------------------------------
 * **Daz** m_check()
 *
 * This command takes as a parameter either a:
 *   - channel
 *   - client
 *   - server
 *   - hostmask
 * ..and returns information relevant to it.
 *
 * Usage: /quote check <[#]param>
 * --------------------------------------------------------
 */
int m_check(struct Client *cptr, struct Client *sptr, int parc, char *parv[])
{
  struct Channel *chptr;
  struct Client *acptr;
  struct Client *acptr2;
  char *param;
  int showchan = 0;
        
  /* Have we got enough parameters? */
  if (parc < 2) {
    sendto_one(sptr, err_str(ERR_NEEDMOREPARAMS), me.name, parv[0], "CHECK");
    return 0;
  }
        
  param = parv[1];
        
  /* Additional option for Check_Hostmask */
  if (parc >= 3)
     if (!strCasediff(parv[2],"-c") || !strCasediff(parv[2],"-channels"))
        showchan = 1;
 
  /* CHANNEL */
  if (IsChannelName(param)) {
     if (chptr = FindChannel(param)) {
        Check_Channel(sptr, chptr, parv[0]);
        Check_Users(sptr, chptr, parv[0]);
     } else
        sendto_one(sptr, err_str(ERR_SEARCHNOMATCH), me.name, parv[0], "CHECK");
  } else {
     /* CLIENT */
     if ((acptr = FindClient(param)) && !(acptr2 = FindServer(param)))
        Check_Client(sptr, acptr, parv[0]);   
     else if (acptr2 = FindServer(param))
        /* SERVER */
        Check_Server(sptr, acptr, parv[0]);
     else if (Check_Hostmask(sptr, param, showchan) == 0)       /* HOSTMASK */ 
        /* Nothing matched - not a channel, client, hostmask or server */
        sendto_one(sptr, err_str(ERR_SEARCHNOMATCH), me.name, parv[0], "CHECK");
  }
}
